@@ -11,17 +11,18 @@ As an "expanded" or "nested" dict, the same data would be:
 """
 
 from collections.abc import Mapping
+from typing import Dict
+
+from cfitall import ConfigValueType
 
 
-def add_keys(destdict, srclist, value=None):
+def add_keys(destdict: dict, srclist: list, value: ConfigValueType = None) -> dict:
     """
     Nests keys from srclist into destdict, with optional value set on the final key.
 
-    :param dict destdict: the dict to update with values from srclist
-    :param list srclist: list of keys to add to destdict
-    :param value: final value to set
-    :return: destination dictionary
-    :rtype: dict
+    :param destdict: dictionary to add keys to
+    :param srclist: list to add keys from
+    :param value: final key's value
     """
     if len(srclist) > 1:
         destdict[srclist[0]] = {}
@@ -32,30 +33,28 @@ def add_keys(destdict, srclist, value=None):
     return destdict
 
 
-def expand_flattened_path(flattened_path, value=None, separator="."):
+def expand_flattened_path(
+    flattened_path: str, value: ConfigValueType = None, separator: str = "."
+) -> dict:
     """
     Expands a dotted path into a nested dict; if value is set, the
     final key in the path will be set to value.
 
-    :param str flattened_path: flattened path to expand
-    :param str separator: character(s) separating path components
-    :param value: set final key to this value
-    :return: nested dictionary
-    :rtype: dict
+    :param flattened_path: the dotted path to expand to a nested dict
+    :param value: final key's value
+    :param separator: separator between dict keys in flattened_path
     """
     split_list = flattened_path.split(separator)
     return add_keys({}, split_list, value)
 
 
-def flatten_dict(nested):
+def flatten_dict(nested: dict) -> dict:
     """
     Flattens a deeply nested dictionary into a flattened dictionary.
     For example `{'foo': {'bar': 'baz'}}` would be flattened to
     `{'foo.bar': 'baz'}`.
 
-    :param dict nested: nested dictionary of configuration data
-    :rtype: dict
-    :return: dict of key-value pairs
+    :param nested: dictionary to flatten
     """
     flattened = {}
     for key, value in nested.items():
@@ -69,20 +68,19 @@ def flatten_dict(nested):
     mappings = [isinstance(value, Mapping) for key, value in flattened.items()]
     if len(set(mappings)) == 1 and set(mappings).pop() is False:
         return flattened
-    else:
+    elif len(set(mappings)) > 0:
         return flatten_dict(flattened)
+    return {}
 
 
-def merge_dicts(source, destination):
+def merge_dicts(source: Mapping, destination: dict) -> dict:
     """
     Performs a deep merge of two nested dicts by expanding all Mapping objects
     until they reach a non-mapping value (e.g. a list, string, int, etc.) and
     copying these from the source to the destination.
 
-    :param dict source: the source dictionary to copy values from
-    :param dict destination: the dictionary to update with values from source
-    :return: destination
-    :rtype: dict
+    :param source: source dictionary to copy from
+    :param destination: destination dict to merge into
     """
     for key, value in source.items():
         key = key.lower() if isinstance(key, str) else key
@@ -94,16 +92,15 @@ def merge_dicts(source, destination):
     return destination
 
 
-def expand_flattened_dict(flattened, separator="."):
+def expand_flattened_dict(flattened: dict, separator: str = ".") -> dict:
     """
-    Expands a flattened dict into a nested dict.
+    Expands a flattened dict into a nested dict, e.g. {'foo.bar': 'baz'} to
+    {'foo': {'bar': 'baz'}}.
 
-    :param dict flattened: the flattened dict to expand
-    :param str separator: character used for separating paths in flattened dict
-    :return: nested dict
-    :rtype: dict
+    :param flattened: dictionary with flattened keys to expand
+    :param separator: separator between dict keys in flattened_path
     """
-    merged = {}
+    merged: Dict[str, ConfigValueType] = {}
     for key, value in flattened.items():
         expanded = expand_flattened_path(key, value=value, separator=separator)
         merged = merge_dicts(merged, expanded)
